@@ -4,7 +4,7 @@ from __future__ import absolute_import
 import datetime
 import pwd
 
-version = '0.21.6.30'
+version = '0.21.7.24'
 
 import os
 import logging
@@ -180,7 +180,7 @@ class TopTrashDirRules:
             return top_trash_dir_valid
 
 
-class TrashDir:
+class TrashDirReader:
 
     def __init__(self, file_reader):
         self.file_reader = file_reader
@@ -200,6 +200,7 @@ class TrashDir:
             if entry.endswith('.trashinfo'):
                 yield os.path.join(info_dir, entry)
 
+
 class ParseError(ValueError): pass
 
 
